@@ -1,5 +1,5 @@
 #create json
-boxplotJSON<-function(data, xlab, ylab, ylim){
+boxplotJSON<-function(data, xlab, ylab, ylim, cex){
 
 data <- data.matrix(data)
 data[is.infinite(data)] <- NA
@@ -19,13 +19,16 @@ data <- list(names=data$names, n=data$n, stats=t(data$stats), out=data$out, grou
 
 labels <- list(x = xlab, y = ylab)
 
-json <- list(data = data, labels = labels, scale = scale)
+if(!is.numeric(cex))
+  cex <- 1
+
+json <- list(data = data, labels = labels, scale = scale, cex = cex)
 
 return(toJSON(json))
 }
 
 
 #create html wrapper for boxplot
-boxplot_rjs<-function(data, xlab = "", ylab = "", ylim = NA, plot = TRUE, jupyter = FALSE, dir = "Boxplot"){
-createHTML(dir, c("d3.min.js","jspdf.min.js","functions.js","boxplot.js"), boxplotJSON(data, xlab, ylab, ylim), plot, jupyter)
+boxplot_rjs<-function(data, xlab = "", ylab = "", ylim = NA, cex = 1, plot = TRUE, jupyter = FALSE, dir = "Boxplot"){
+createHTML(dir, c("d3.min.js","jspdf.min.js","functions.js","boxplot.js"), boxplotJSON(data, xlab, ylab, ylim, cex), plot, jupyter)
 }
